diff --git a/include/PConfig.php b/include/PConfig.php
index d8d6e58f3..9ef113699 100644
--- a/include/PConfig.php
+++ b/include/PConfig.php
@@ -201,7 +201,7 @@ class PConfig {
 	 *  The configuration key to delete
 	 * @return mixed
 	 */
-	public static function del($uid,$family,$key) {
+	public static function delete($uid,$family,$key) {
 
 		global $a;
 		if(x($a->config[$uid][$family],$key))
diff --git a/include/config.php b/include/config.php
index db6c72ee6..585caf43a 100644
--- a/include/config.php
+++ b/include/config.php
@@ -283,7 +283,7 @@ function set_pconfig($uid,$family,$key,$value) {
 /**
  * @brief (Deprecated) Deletes the given key from the users's configuration.
  *
  * Note: This function is deprecated. Use PConfig::del() instead.
  *
  * @param string $uid The user_id
  * @param string $family
@@ -293,5 +293,5 @@ function set_pconfig($uid,$family,$key,$value) {
  * @return mixed
  */
 function del_pconfig($uid,$family,$key) {
-	return PConfig::del($uid, $family, $key);
+	return PConfig::delete($uid, $family, $key);
 }
@@ -283,7 +283,7 @@ function set_pconfig($uid,$family,$key,$value) {
  * @brief (Deprecated) Deletes the given key from the users's configuration.
  *
- * Note: This function is deprecated. Use PConfig::del() instead.
+ * Note: This function is deprecated. Use PConfig::delete() instead.
  *
  * @param string $uid The user_id